-- airport.lua: O.M.G. (Openworld MiniGames) [nclok1405]

-- Set to false to disable map icons
OMG_DISPLAY_MAP_ICON = true

--[[
	OK, let me explain what is a "District Script" and why I chose to mod it.
	The District Scripts is a set of Lua scripts that are loaded by sr2_city.lua, the master Lua script which is loaded during freeroam.

	Volition's intension of the District Scripts was probably to code custom behaviors or events for each district
	such as setting pedestrians category, setting minimum notoriety level, and spawning special weapons.
	In the released SR2 game, district scripts are mostly unused, but still loaded and executed by sr2_city.lua.

	I chose to mod this district script instead of sr2_city.lua, because by doing this, this mod can easily co-exist with Sandbox+ mods.
--]]

OMG_WEAPON_SLOT_NAMES = {
	[WEAPON_SLOT_UNARMED] = "unarmed",
	[WEAPON_SLOT_MELEE] = "melee",
	[WEAPON_SLOT_PISTOL] = "pistol",
	[WEAPON_SLOT_SMG] = "smg",
	[WEAPON_SLOT_SHOTGUN] = "shotgun",
	[WEAPON_SLOT_RIFLE] = "rifle",
	[WEAPON_SLOT_LAUNCHER] = "launcher",
	[WEAPON_SLOT_THROWN] = "thrown",
}

OMG_STATUS_INACTIVE = 0
OMG_STATUS_RAMPAGE = 1
OMG_STATUS_TRANSPORT = 2

OMG_GAMETYPE_RAMPAGE = 0
OMG_GAMETYPE_TRANSPORT = 1

OMG_LOCATIONS = {
	{
		navpoint = "mission_start_sr2_city_$tss03",
		name = "Yakuza Burner",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "tss03",
		reward = 3000,
		time_limit = 120,
		kills = 25,
		target_team = "Ronin",
		notoriety_police = 0,
		notoriety_brotherhood = 0,
		notoriety_ronin = 5,
		notoriety_samedi = 0,
		weapon_name = "flamethrower",
		weapon_ammo = 200,
		weapon_slot = WEAPON_SLOT_LAUNCHER,
		only_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "mission_start_sr2_city_$ss01",
		name = "AK Firefight",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "ss01",
		reward = 2000,
		time_limit = 120,
		kills = 20,
		target_team = "Samedi",
		notoriety_police = 0,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 5,
		weapon_name = "ak47",
		weapon_ammo = 300,
		weapon_slot = WEAPON_SLOT_RIFLE,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "sr2_city_$sh_bh_docks",
		name = "Molotov Attack",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "sh_bh_docks",
		reward = 3000,
		time_limit = 180,
		kills = 20,
		target_team = "Brotherhood",
		notoriety_police = 0,
		notoriety_brotherhood = 5,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "molotov",
		weapon_ammo = 100,
		weapon_slot = WEAPON_SLOT_THROWN,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "mission_start_sr2_city_$rn09",
		name = "Texas Chainsaw",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "rn09",
		reward = 1500,
		time_limit = 120,
		kills = 20,
		target_team = "",
		notoriety_police = 2,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "chainsaw",
		weapon_ammo = 1,
		weapon_slot = WEAPON_SLOT_MELEE,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "sr2_city_$sh_rn_museum_pier",
		name = "Roadkill Museum",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "sh_rn_museum_pier",
		reward = 2000,
		time_limit = 120,
		kills = 30,
		target_team = "",
		notoriety_police = 0,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "",
		weapon_ammo = 0,
		weapon_slot = WEAPON_SLOT_UNARMED,
		only_vehicle_kills = true,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "mission_start_sr2_city_$ep01",
		name = "Slap Everyone",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "ep01",
		reward = 1500,
		time_limit = 180,
		kills = 30,
		target_team = "",
		notoriety_police = 1,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "pimp_slap",
		weapon_ammo = 1,
		weapon_slot = WEAPON_SLOT_MELEE,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "mission_start_sr2_city_$em01_julius_file",
		name = "Rampage on Precinct 31",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "em01",
		reward = 2000,
		time_limit = 120,
		kills = 20,
		target_team = "Police",
		notoriety_police = 1,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "any",
		weapon_ammo = 0,
		weapon_slot = WEAPON_SLOT_UNARMED,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = true,
		human_shield_allowed = true,
	},
	{
		navpoint = "exploration_marina_pirateship",
		name = "Arr...",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "tss02",
		reward = 1000,
		time_limit = 120,
		kills = 15,
		target_team = "",
		notoriety_police = 2,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "pirate_hook",
		weapon_ammo = 1,
		weapon_slot = WEAPON_SLOT_MELEE,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},
	{
		navpoint = "ultor_base_$i000",
		name = "Unforeseen Consequences",
		gametype = OMG_GAMETYPE_RAMPAGE,
		unlock_after = "tss02",
		reward = 1000,
		time_limit = 120,
		kills = 15,
		target_team = "",
		notoriety_police = 1,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		weapon_name = "tire_iron",
		weapon_ammo = 1,
		weapon_slot = WEAPON_SLOT_MELEE,
		only_vehicle_kills = false,
		allow_both_onfoot_and_vehicle_kills = false,
		human_shield_allowed = false,
	},

	{
		navpoint = "exploration_pierce_mansion",
 		name = "Price's Legacy",
		gametype = OMG_GAMETYPE_TRANSPORT,
		unlock_after = "tss02",
		reward = 2000,
		time_limit = 180,
		notoriety_police = 4,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		goal_navpoint = "garage_sr2_city_$SHQ_interior",
		goal_radius = 10,
	},
	{
		navpoint = "airport_$push01",
 		name = "Club Dash",
		gametype = OMG_GAMETYPE_TRANSPORT,
		unlock_after = "tss02",
		reward = 2000,
		time_limit = 180,
		notoriety_police = 4,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		goal_navpoint = "shops_sr2_city_$HER_bar_store",
		goal_radius = 5,
	},
	{
		navpoint = "exploration_un_observatory",
 		name = "Observation",
		gametype = OMG_GAMETYPE_TRANSPORT,
		unlock_after = "tss02",
		reward = 1500,
		time_limit = 180,
		notoriety_police = 3,
		notoriety_brotherhood = 0,
		notoriety_ronin = 0,
		notoriety_samedi = 0,
		goal_navpoint = "chinatown_$push2_01",
		goal_radius = 5,
	},
}

omg_status = 0
omg_message_delay = 0
omg_trigger_effect_is_probably_active = false
omg_player_is_in_trigger = false
omg_timer = 0
omg_countdown = 15
omg_cancel_timer = 0
omg_active = {}
omg_rampage_kill_count = 0
omg_rampage_target_team = ""

function airport_init()
end

function airport_main()
	-- This function is started while the game is still being loaded.
	-- Wait until the player(s) are ready to respond.
	while (not character_is_ready(LOCAL_PLAYER)) do
		thread_yield()
	end
	if coop_is_active() then
		while (not character_is_ready(REMOTE_PLAYER)) do
			thread_yield()
		end
	end

	--teleport_coop("exploration_un_observatory","exploration_un_observatory")

	while true do
		-- Timers
		if omg_message_delay > 0 then
			omg_message_delay = omg_message_delay - get_frame_time()
		end
		if omg_timer > 0 then
			omg_timer = omg_timer - get_frame_time()
		end
		if (omg_timer > 0) and (omg_timer < omg_countdown) then
			-- Play Countdown Sound
			audio_play("SYS_HUD_CNTDWN_NEG")
			omg_countdown = omg_countdown - 1
		end
		if omg_cancel_timer > 0 then
			omg_cancel_timer = omg_cancel_timer - get_frame_time()
		end
		
		-- Main Codes
		if omg_status == OMG_STATUS_INACTIVE then
			omg_inactive()
		elseif omg_status == OMG_STATUS_RAMPAGE then
			omg_rampage_main()
		elseif omg_status == OMG_STATUS_TRANSPORT then
			omg_transport_main()
		end
		
		thread_yield()
	end
end

-- debug function - call from the console with 'lua' command
function warp_airport()
	message("warping...")
	delay(0)
	teleport("#PLAYER#", "airport_$nav-warp")
end

-- Returns true if both players are dead
function omg_is_both_players_dead()
	if coop_is_active() then
		if (get_current_hit_points(LOCAL_PLAYER) <= 0) and (get_current_hit_points(REMOTE_PLAYER) <= 0) then
			return true
		end
	else
		if (get_current_hit_points(LOCAL_PLAYER) <= 0) then
			return true
		end
	end
	return false
end

-- Add start markers
-- Note to self: The max number of markers is 64
function omg_add_trigger_effects()
	for index, location in pairs(OMG_LOCATIONS) do
		if mission_is_complete(location.unlock_after) then
			if OMG_DISPLAY_MAP_ICON then
				marker_add_navpoint(location.navpoint, "map_other_hidden_mission", INGAME_EFFECT_LOCATION, SYNC_ALL)
			else
				ingame_effect_add_navpoint(location.navpoint, INGAME_EFFECT_LOCATION, SYNC_ALL)
			end
		end
	end
end

-- Remove start markers
function omg_remove_trigger_effects()
	for index, location in pairs(OMG_LOCATIONS) do
		if OMG_DISPLAY_MAP_ICON then
			marker_remove_navpoint(location.navpoint, SYNC_ALL)
		else
			ingame_effect_remove_navpoint(location.navpoint, SYNC_ALL)
		end
	end
end

-- Freeroam
function omg_inactive()
	-- If currently in mission
	if mission_is_active() then
		-- Remove any triggers
		if omg_trigger_effect_is_probably_active then
			omg_remove_trigger_effects()
			omg_trigger_effect_is_probably_active = false
		end
		
		-- Wait until the mission is over
		while mission_is_active() do
			thread_yield()
		end
	end

	-- Add triggers
	if not omg_trigger_effect_is_probably_active then
		omg_trigger_effect_is_probably_active = true
		omg_add_trigger_effects()
	end
	
	local player_on_trigger_now = false
	if (not mission_is_active()) and (not character_is_in_vehicle(LOCAL_PLAYER)) then
		for index, location in pairs(OMG_LOCATIONS) do
			if mission_is_complete(location.unlock_after) then
				if (get_dist_char_to_nav(LOCAL_PLAYER, location.navpoint) < 1) then
					-- Show "Press E to start" message
					if (not omg_player_is_in_trigger) then
						audio_play("SYS_HUD_HELPTEXT")
						if location.gametype == OMG_GAMETYPE_RAMPAGE then
							mission_help_table_nag("Press {ACTION_IMG} to start Rampage: "..tostring(location.name), "", "", SYNC_LOCAL)
						elseif location.gametype == OMG_GAMETYPE_TRANSPORT then
							mission_help_table_nag("Press {ACTION_IMG} to start Transport: "..tostring(location.name), "", "", SYNC_LOCAL)
						end
					end
					player_on_trigger_now = true
					omg_player_is_in_trigger = true
				end
				
				-- Start gameplay
				if player_button_just_pressed(4) and (get_dist_char_to_nav(LOCAL_PLAYER, location.navpoint) < 1) then -- PC_BTN_ACTION
					audio_play("SYS_OBJECTIVE_COMPLETE")
					
					omg_rampage_kill_count = 0
					omg_countdown = 15
					
					omg_active = location
					omg_timer = location.time_limit

					notoriety_set("Police", location.notoriety_police)
					notoriety_set("Brotherhood", location.notoriety_brotherhood)
					notoriety_set("Ronin", location.notoriety_ronin)
					notoriety_set("Samedi", location.notoriety_samedi)
					notoriety_set_min("Police", location.notoriety_police)
					notoriety_set_min("Brotherhood", location.notoriety_brotherhood)
					notoriety_set_min("Ronin", location.notoriety_ronin)
					notoriety_set_min("Samedi", location.notoriety_samedi)
					
					set_player_can_be_busted(LOCAL_PLAYER, false)	-- Disable busting since I can't reliably detect it
					if coop_is_active() then
						set_player_can_be_busted(REMOTE_PLAYER, false)
					end
					
					if location.gametype == OMG_GAMETYPE_RAMPAGE then
						if location.weapon_name ~= "any" then
							-- Set weapon
							inv_item_remove_in_slot(OMG_WEAPON_SLOT_NAMES[location.weapon_slot], LOCAL_PLAYER)
							if location.weapon_name ~= "" then
								inv_item_add(location.weapon_name, location.weapon_ammo, LOCAL_PLAYER, true)
							end
							if coop_is_active() then
								inv_item_remove_in_slot(OMG_WEAPON_SLOT_NAMES[location.weapon_slot], REMOTE_PLAYER)
								if location.weapon_name ~= "" then
									inv_item_add(location.weapon_name, location.weapon_ammo, REMOTE_PLAYER, true)
								end
							end
							inv_weapon_disable_all_but_this_slot(location.weapon_slot, SYNC_ALL)
						end
						
						local team = "people"
						if location.target_team == "Police" then
							team = "Police Officers"
						elseif location.target_team == "Brotherhood" then
							team = "Brotherhood Members"
						elseif location.target_team == "Ronin" then
							team = "Ronin Members"
						elseif location.target_team == "Samedi" then
							team = "Samedi Members"
						end
						
						if location.only_vehicle_kills then
							mission_help_table_nag("Kill "..tostring(location.kills).." [format][color:red]"..team.."[/format] in "..tostring(location.time_limit).." seconds using vehicles!", "", "", SYNC_ALL)
						else
							mission_help_table_nag("Kill "..tostring(location.kills).." [format][color:red]"..team.."[/format] in "..tostring(location.time_limit).." seconds!", "", "", SYNC_ALL)
						end
						
						on_notoriety_event("omg_notoriety_event_local_player", LOCAL_PLAYER)
						if coop_is_active() then
							on_notoriety_event("omg_notoriety_event_remote_player", REMOTE_PLAYER)
						end

						omg_status = OMG_STATUS_RAMPAGE
					elseif location.gametype == OMG_GAMETYPE_TRANSPORT then
						mission_help_table_nag("Go to the [format][color:teal]destination[/format] in "..tostring(location.time_limit).." seconds! Do NOT use a Taxi!", "", "", SYNC_ALL)
						marker_add_navpoint(location.goal_navpoint, MINIMAP_ICON_LOCATION, INGAME_EFFECT_LOCATION, SYNC_ALL)
						mission_waypoint_add(location.goal_navpoint)
						omg_status = OMG_STATUS_TRANSPORT
					end
					
					omg_remove_trigger_effects()
					omg_trigger_effect_is_probably_active = false
					
					omg_message_delay = 5
					return
				end
			end
		end
	end
	
	if (not player_on_trigger_now) and omg_player_is_in_trigger then
		-- If the player has left the trigger, clear the on-screen message quickly
		mission_help_clear()
		omg_player_is_in_trigger = false
	end
end

-- Called when the players commit crime. This is the only way I could do to detect random ped kills.
function omg_notoriety_event_local_player(event, police, gang, team)
	omg_notoriety_event_do(LOCAL_PLAYER, event, police, gang, team)
end
function omg_notoriety_event_remote_player(event, police, gang, team)
	omg_notoriety_event_do(REMOTE_PLAYER, event, police, gang, team)
end
function omg_notoriety_event_do(player, event, police, gang, team)
	if (omg_status == OMG_STATUS_RAMPAGE) then
		if (event == "gang kill") or (event == "police kill") or (event == "civilian kill") then
			if (event ~= "police kill") and (omg_active.target_team == "Police") then
				return	-- Do not count civilians on Police Rampage
			end
		
			if (omg_active.target_team == "") or (omg_active.target_team == team) then
				if omg_active.allow_both_onfoot_and_vehicle_kills or ((not omg_active.only_vehicle_kills) and (not character_is_in_vehicle(player))) or (omg_active.only_vehicle_kills and character_is_in_vehicle(player)) then
					omg_rampage_kill_count = omg_rampage_kill_count + 1
					audio_play("SYS_MAYHEM_CHING")
				end
			end
		end
	end
end

function omg_rampage_main()
	-- If Human Shielding is not allowed, force release them
	if (not omg_active.human_shield_allowed) then
		if character_has_human_shield(LOCAL_PLAYER) then
			character_release_human_shield(LOCAL_PLAYER)
		end
		if coop_is_active() and character_has_human_shield(REMOTE_PLAYER) then
			character_release_human_shield(REMOTE_PLAYER)
		end
	end
	
	-- Cancel Rampage
	local cancel_flag = false
	if player_button_just_pressed(11) then -- PC_DPAD_DOWN
		if omg_cancel_timer <= 0 then
			audio_play("SYS_HUD_ACTIVATE")
			mission_help_clear()
			mission_help_table_nag("Press {CANCEL_ACTIVITY} again to cancel Rampage", "", "", SYNC_ALL)
			omg_message_delay = 3
			omg_cancel_timer = 3
		else
			cancel_flag = true
		end
	end
	
	-- Check if failed
	local failed = false
	if (omg_timer <= 0) or mission_is_active() or omg_is_both_players_dead() or cancel_flag then
		failed = true
	end
	
	if failed then
		-- Failure
		audio_play("SYS_RACE_FAIL")
		
		if omg_is_both_players_dead() then
			-- If the players died, wait until they respawn
			while omg_is_both_players_dead() do
				thread_yield()
			end
			-- Respawn them to the start
			teleport_coop(omg_active.navpoint, omg_active.navpoint)
		end
		
		mission_help_clear()
		mission_help_table_nag("Rampage Failed. You killed only "..tostring(omg_rampage_kill_count).." of "..tostring(omg_active.kills).." targets.", "", "", SYNC_ALL)
		omg_rampage_cleanup()
		delay(5)
	elseif omg_rampage_kill_count >= omg_active.kills then
		-- Success
		audio_play("SYS_RACE_FINISH")
		mission_help_clear()
		mission_help_table_nag("Rampage Completed! Reward: $"..tostring(omg_active.reward), "", "", SYNC_ALL)
		cash_add(omg_active.reward, LOCAL_PLAYER)
		if coop_is_active() then
			cash_add(omg_active.reward, REMOTE_PLAYER)
		end
		omg_rampage_cleanup()
		delay(5)
	else
		-- In-Game
		if omg_message_delay <= 0 then
			mission_help_table_nag("Time:"..tostring(floor(omg_timer))..", Kills:"..tostring(omg_rampage_kill_count).."/"..tostring(omg_active.kills), "", "", SYNC_ALL)
			mission_help_clear()
			omg_message_delay = 0.5
		end
	end
end

function omg_rampage_cleanup()
	inv_weapon_disable_slot(WEAPON_SLOT_UNARMED, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_MELEE, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_PISTOL, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_SMG, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_SHOTGUN, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_RIFLE, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_LAUNCHER, false, SYNC_ALL)
	inv_weapon_disable_slot(WEAPON_SLOT_THROWN, false, SYNC_ALL)

	notoriety_set_min("Police", 0)
	notoriety_set_min("Brotherhood", 0)
	notoriety_set_min("Ronin", 0)
	notoriety_set_min("Samedi", 0)
	notoriety_set("Police", 0)
	notoriety_set("Brotherhood", 0)
	notoriety_set("Ronin", 0)
	notoriety_set("Samedi", 0)

	on_notoriety_event("", LOCAL_PLAYER)
	if coop_is_active() then
		on_notoriety_event("", REMOTE_PLAYER)
	end

	set_player_can_be_busted(LOCAL_PLAYER, true)
	if coop_is_active() then
		set_player_can_be_busted(REMOTE_PLAYER, true)
	end

	if omg_active.gametype == OMG_GAMETYPE_TRANSPORT then
		mission_waypoint_remove()
		marker_remove_navpoint(omg_active.goal_navpoint, SYNC_ALL)
	end

	omg_timer = 0
	omg_status = OMG_STATUS_INACTIVE
end

function omg_transport_main()
	local fail_reason = ""

	-- Cancel Transport
	local cancel_flag = false
	if player_button_just_pressed(11) then -- PC_DPAD_DOWN
		if omg_cancel_timer <= 0 then
			audio_play("SYS_HUD_ACTIVATE")
			mission_help_clear()
			mission_help_table_nag("Press {CANCEL_ACTIVITY} again to cancel Transport", "", "", SYNC_ALL)
			omg_message_delay = 3
			omg_cancel_timer = 3
		else
			cancel_flag = true
		end
	end
	
	-- Check failures
	if cancel_flag then
		fail_reason = "You cancelled the deal."
	elseif (omg_timer <= 0) then
		fail_reason = "Time is up! The buyer has left."
	elseif mission_is_active() then
		fail_reason = "You started a mission or an activity."
	elseif omg_is_both_players_dead() then
		fail_reason = "You died."
	elseif (get_char_vehicle_special_type(LOCAL_PLAYER) == VST_TAXI) and (not character_is_in_a_driver_seat(LOCAL_PLAYER)) then
		fail_reason = "I said you must NOT use a Taxi! The buyer is angry!"
	end
	
	if fail_reason ~= "" then
		-- Failure
		audio_play("SYS_RACE_FAIL")
		
		if omg_is_both_players_dead() then
			-- If the players died, wait until they respawn
			while omg_is_both_players_dead() do
				thread_yield()
			end
			-- Respawn them to the start
			teleport_coop(omg_active.navpoint, omg_active.navpoint)
		end
		
		mission_help_clear()
		mission_help_table_nag("Transport Failed. "..fail_reason, "", "", SYNC_ALL)
		omg_rampage_cleanup()
		delay(5)
	elseif get_dist_char_to_nav(LOCAL_PLAYER, omg_active.goal_navpoint) < omg_active.goal_radius then
		-- Success
		audio_play("SYS_RACE_FINISH")
		mission_help_clear()
		mission_help_table_nag("Transport Completed! Reward: $"..tostring(omg_active.reward), "", "", SYNC_ALL)
		cash_add(omg_active.reward, LOCAL_PLAYER)
		if coop_is_active() then
			cash_add(omg_active.reward, REMOTE_PLAYER)
		end
		omg_rampage_cleanup()
		delay(5)
	else
		-- In-Game
		if omg_message_delay <= 0 then
			mission_help_table_nag("Time:"..tostring(floor(omg_timer)), "", "", SYNC_ALL)
			mission_help_clear()
			omg_message_delay = 0.5
		end
	end
end

